package cd.casic.module.machine.controller;
import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.module.machine.entity.SecretKey;
import cd.casic.module.machine.service.SecretKeyService;
import cd.casic.module.machine.dto.SecretKeyDto;
import cd.casic.module.machine.utils.PageResult;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import org.springframework.core.io.InputStreamResource;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RequestPart;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

import static cd.casic.framework.commons.pojo.CommonResult.success;

@RestController
@RequestMapping("/api/secretKey")
@Tag(name =  "密钥管理")
public class SecretKeyController {
    @Resource
    private SecretKeyService secretKeyService;

    @PostMapping(value = "/add", consumes = "multipart/form-data")
    @Operation(summary ="新增密钥")
    public CommonResult<Boolean> add(@RequestBody SecretKeyDto secretKeyDto, @RequestPart("file") MultipartFile file) {
        return success(secretKeyService.addSecretKey(secretKeyDto, file));
    }

    @PutMapping("/bindingMachine")
    @Operation(summary ="绑定机器")
    public CommonResult<Boolean> bindingMachine(@RequestParam("secretKeyId") Long secretKeyId, @RequestParam("machineInfoIds") List<Long> machineInfoIds) {
        secretKeyService.bindingMachine(secretKeyId, machineInfoIds);
        return success(true);
    }

    @PutMapping("/update")
    @Operation(summary ="编辑密钥信息")
    public CommonResult<Boolean> update(@RequestBody SecretKeyDto secretKeyDto, @RequestPart(value = "file", required = false) MultipartFile file) {
        return success(secretKeyService.updateSecretKey(secretKeyDto, file));
    }


    @DeleteMapping("/delete")
    @Operation(summary ="删除密钥")
    public CommonResult<Boolean> delete(@RequestParam("secretKeyId") Long secretKeyId) {
        return success(secretKeyService.deleteSecretKey(secretKeyId));
    }

    @DeleteMapping("/deleteList")
    @Operation(summary ="批量删除密钥")
    public CommonResult<Boolean> deleteList(@RequestParam("secretKeyId") List<Long> secretKeyIds) {
        return success(secretKeyService.deleteList(secretKeyIds));
    }

    @GetMapping("/list")
    @Operation(summary ="获取密钥信息列表")
    public CommonResult<PageResult<SecretKey>> list(@RequestBody SecretKeyDto secretKeyDto) {
        return success(secretKeyService.listSecretKey(secretKeyDto));
    }

    @GetMapping("/downloadSecretKeyFile")
    @Operation(summary ="下载密钥文件")
    public CommonResult<InputStreamResource> downloadSecretKeyFile(@RequestParam("secretKeyId") Long secretKeyId) {
        return success(secretKeyService.downloadSecretKeyFile(secretKeyId).getBody());
    }
}
